@@ -6,7 +6,7 @@ use warnings;
 use lib qw|lib/ t/lib/ t/lib/RabbitMQ/ t/brokers/|;
 
 use Moose;
-with 'RabbitMQ::TestWorker', 'FailsOnceWorker' => { -excludes => [ 'configuration' ], };
+with 'RabbitMQ::TestWorker', 'FailsOnceWorker' => { -excludes => [ 'configuration', 'lazy_queue' ], };
 
 no Moose;
 
